(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     77402,       1727]
NotebookOptionsPosition[     38254,        975]
NotebookOutlinePosition[     70514,       1636]
CellTagsIndexPosition[     70471,       1633]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["SRG and NCSM", "Title",
 CellChangeTimes->{{3.515241323603434*^9, 
  3.515241345381414*^9}},ExpressionUUID->"6a616d33-8ac1-49f2-99d6-\
e5224779036d"],

Cell["\<\
SRG evolution in three-nucleon space
NCSM solution for the triton \
\>", "Subtitle",
 CellChangeTimes->{{3.515241349865473*^9, 3.5152414124715652`*^9}, {
  3.645433095378317*^9, 
  3.645433097796411*^9}},ExpressionUUID->"a216c7a2-10b5-4abe-b8da-\
2459c0bf4b41"],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 CellChangeTimes->{{3.5152989666610193`*^9, 
  3.51529896921885*^9}},ExpressionUUID->"6b2456ea-3953-43d3-8356-\
df5168df1ab1"],

Cell["\<\
Here are some constants that will be needed later-on as well as some optional \
settings for the graphics output. Please evaluate these cells when you start \
working with this notebook.\
\>", "Item",
 CellChangeTimes->{{3.515300112086081*^9, 3.5153001724754868`*^9}, {
  3.515308974485653*^9, 3.515308981633462*^9}, {3.6454331058515997`*^9, 
  3.645433107865551*^9}},ExpressionUUID->"3c36995d-931a-4f0b-abd8-\
86e4a9e962e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hbarc", "=", "197.327053"}], ";", "                 ", 
  RowBox[{"(*", " ", 
   RowBox[{"[", 
    RowBox[{"MeV", " ", "fm"}], "]"}], " ", "*)"}], "\n", 
  RowBox[{"MN0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"938.27231", " ", "+", " ", "939.56563"}], ")"}], "/", "2"}]}], 
  ";", "   ", 
  RowBox[{"(*", " ", 
   RowBox[{"average", " ", "nucleon", " ", 
    RowBox[{"mass", " ", "[", "MeV", "]"}]}], " ", "*)"}], "\n", 
  RowBox[{"MN", "=", 
   RowBox[{"MN0", "/", 
    RowBox[{"hbarc", "^", "2"}]}]}], " ", ";", "     \t\t\t", 
  RowBox[{"(*", " ", 
   RowBox[{"average", " ", "nucleon", " ", "mass", " ", "in", " ", 
    RowBox[{"units", " ", "[", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"MeV", " ", 
        RowBox[{"fm", "^", "2"}]}], ")"}]}], "]"}]}], " ", "*)"}]}]], "Input",\

 CellChangeTimes->{{3.444448011601282*^9, 3.444448013848761*^9}, {
  3.5152442119971457`*^9, 3.515244288070447*^9}, {3.51529193401068*^9, 
  3.5152919369055233`*^9}, {3.515300053196741*^9, 3.515300101604507*^9}, {
  3.823510695591529*^9, 
  3.823510750784952*^9}},ExpressionUUID->"8c245e44-5e1f-47d0-95df-\
7d248bf90e62"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ArrayPlot", ",", " ", 
    RowBox[{"ColorFunction", "\[Rule]", "\"\<SunsetColors\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"DensityPlot", ",", " ", 
    RowBox[{"ColorFunction", "\[Rule]", "\"\<SunsetColors\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ListDensityPlot", ",", " ", 
    RowBox[{"ColorFunction", "\[Rule]", "\"\<SunsetColors\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ListLinePlot", ",", " ", 
    RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"Axes", "\[Rule]", "False"}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "0.8"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.515290480026371*^9, 3.515290500351708*^9}, {
  3.515299534606942*^9, 3.5152995581868963`*^9}, {3.515299888932732*^9, 
  3.515299893000996*^9}, {3.515300654892482*^9, 3.515300670120162*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"2c0766ee-c797-4dc4-b16d-51fbb7300adc"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initial Hamiltonian", "Section",
 CellChangeTimes->{{3.515257884379283*^9, 3.515257889372558*^9}, {
  3.515290674410906*^9, 
  3.515290674826132*^9}},ExpressionUUID->"df1c4a51-30b7-49fc-8490-\
ee29f77d7c5a"],

Cell[TextData[{
 "In this project we solve the quantum many-body problem for the ground state \
of the triton (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[InvisiblePrefixScriptBase]", "3"], "H"}], 
   TraditionalForm]],ExpressionUUID->"b6ef8634-e743-433c-b366-3ff131078c99"],
 ") using an SRG-transformed chiral Hamiltonian in the No-Core Shell Model."
}], "Item",
 CellChangeTimes->{{3.51528972467844*^9, 3.515289828702935*^9}, {
  3.5153031505250463`*^9, 3.515303209732542*^9}, {3.6454333260278177`*^9, 
  3.645433328749219*^9}},ExpressionUUID->"506d407b-60bd-45a3-adb3-\
beedd368d66e"],

Cell["\<\
In a first step, we prepare the initial Hamiltonian, which is given in a \
matrix representation using a three-body Jacobi-coordinate \
harmonic-oscillator basis. Those matrix elements are provided via external \
data files. \
\>", "Item",
 CellChangeTimes->{{3.515289833681922*^9, 3.515289953428165*^9}, {
   3.645888740486977*^9, 3.645888740574836*^9}, 
   3.706974526001523*^9},ExpressionUUID->"ae85637c-6196-4434-b611-\
bada22df0feb"],

Cell["\<\
The initial Hamiltonian is composed of the kinetic energy T and the \
interaction V, which in our case is the most recent chiral two- plus \
three-nucleon interaction used also in the lecture on ab initio methods. \
\>", "Item",
 CellChangeTimes->{{3.5152579011614723`*^9, 3.51525793870011*^9}, {
  3.51528998202815*^9, 
  3.515290058120118*^9}},ExpressionUUID->"5b9e8d04-d3cb-4ec1-8674-\
313881dc0167"],

Cell["\<\
In order to allow for numerical calculations, these two operators have to be \
represented in a suitable basis, i.e., the matrix elements of the operators \
for all combinations of two basis states are used as input. The basis of \
choice for the present application in the three-nucleon system is a \
antisymmetrized three-body Jacobi-coordinate harmonic oscillator basis. This \
basis never appears explicitly in this notebook (because it's quite \
complicated), but it was used to compute the matrix elements which are \
provided in the data files.  \
\>", "Item",
 CellChangeTimes->{{3.515290071600205*^9, 3.515290272464521*^9}, {
  3.515303266606062*^9, 
  3.515303298930769*^9}},ExpressionUUID->"dd9d04b2-b0f2-4253-ba61-\
9949b337c59b"],

Cell["\<\
First we have to set the working directory to the place, where you have put \
the matrix element files. You might have to change the following statement \
accordingly.\
\>", "Item",
 CellChangeTimes->{{3.515290274249484*^9, 3.515290323571677*^9}, 
   3.515290386491825*^9, {3.515303331151115*^9, 3.515303332615052*^9}, 
   3.6458887307155533`*^9},ExpressionUUID->"8ff113e9-249a-4386-a07f-\
941c13d0e7b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", "\"\<~/Desktop/\>\"", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5152414309623117`*^9, 3.51524145395592*^9}, 
   3.5152415227025337`*^9, 3.645433506648342*^9},
 CellLabel->"In[8]:=",ExpressionUUID->"c4d47fdc-5ad8-471f-bd25-88f9f50d1dfb"],

Cell["\<\
The following commands read in the kinetic energy and the interaction matrix \
elements from the two files and store them in two matrix-type variables TMat \
and VMat, respectively.  \
\>", "Item",
 CellChangeTimes->{{3.51525810193097*^9, 3.515258134813878*^9}, {
   3.515290338330676*^9, 3.5152903829486*^9}, 
   3.515303372938512*^9},ExpressionUUID->"6c5b0791-fa82-4f6b-aa04-\
003d9f012999"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TMat", " ", "=", " ", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<kinetic_EMax20_hw20.dat\>\"", ",", " ", "\"\<Table\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VMat", " ", "=", " ", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<chi2b3b_EMax20_hw20.dat\>\"", ",", " ", "\"\<Table\>\""}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.515241457693*^9, 3.515241537589781*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"0c9202ec-3464-4111-a9da-2cf836d69710"],

Cell["\<\
First we visualize these matrices. We use the ArrayPlot[] command to plot the \
absolute values of the kinetic energy (TMat) and the potential matrix \
elements (VMat), respectively. What do you observe?\
\>", "Item",
 CellChangeTimes->{{3.515290433045863*^9, 3.5152904723841877`*^9}, {
   3.5152905318522043`*^9, 3.51529062167216*^9}, {3.515303393576223*^9, 
   3.51530350905182*^9}, 
   3.7069745325397882`*^9},ExpressionUUID->"ca2a6205-848a-4166-a31c-\
56bbe73c1f82"],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{
   RowBox[{"Abs", "[", "TMat", "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "3"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5152416366386747`*^9, 3.515241697121607*^9}, {
  3.515241766260994*^9, 3.5152417899086647`*^9}, {3.515258074918631*^9, 
  3.515258075132804*^9}, {3.515290489158332*^9, 3.515290518383992*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"f279bb66-2c0f-4cbc-be3b-e7f652300072"],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{
   RowBox[{"Abs", "[", "VMat", "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "3"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5152416366386747`*^9, 3.515241697121607*^9}, {
   3.515241766260994*^9, 3.5152417899086647`*^9}, {3.515258074918631*^9, 
   3.515258075132804*^9}, 3.515290489158332*^9},
 CellLabel->"In[12]:=",ExpressionUUID->"abd45905-2855-41b7-b162-3be873293cfc"]
}, Closed]],

Cell[CellGroupData[{

Cell["SRG Evolution", "Section",
 CellChangeTimes->{{3.515258007950039*^9, 3.515258010745205*^9}, 
   3.515290681523039*^9},ExpressionUUID->"8b94ebfe-6512-4e34-bb7b-\
b7893150f66f"],

Cell[CellGroupData[{

Cell["Formalism and Algorithm", "Subsection",
 CellChangeTimes->{{3.515291758230986*^9, 
  3.515291764754567*^9}},ExpressionUUID->"c3c1a581-6ce3-4b9f-a8d0-\
dde689498442"],

Cell["\<\
Now we implement the SRG-evolution of the Hamiltonian using the kinetic \
energy and potential matrix elements from above.  \
\>", "Item",
 CellChangeTimes->{{3.515290705186389*^9, 3.5152907775259037`*^9}, 
   3.515303524850595*^9},ExpressionUUID->"53617733-b79f-43a6-b109-\
85a440a9b6b8"],

Cell["\<\
We start from the evolution equation for the operators with a flow parameter \
a and expand the commutators\
\>", "Item",
 CellChangeTimes->{{3.5152907866872*^9, 3.515290795510211*^9}, {
  3.515290930806711*^9, 3.515290988838176*^9}, {3.515291124484702*^9, 
  3.515291137771965*^9}, {3.515303762873646*^9, 
  3.515303783543899*^9}},ExpressionUUID->"3ac2edc5-c568-4862-b3f0-\
3377de7bb4e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["d", "da"], 
   RowBox[{"H", "[", "a", "]"}]}], " ", "=", " ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", 
    RowBox[{
     SuperscriptBox["MN", "2"], " ", "[", 
     RowBox[{
      RowBox[{"[", 
       RowBox[{"T", ",", 
        RowBox[{"H", "[", "a", "]"}]}], "]"}], ",", " ", 
      RowBox[{"H", "[", "a", "]"}]}], "]"}]}], "=", " ", 
   RowBox[{
    SuperscriptBox["MN", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"T", " ", 
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{"H", "[", "a", "]"}]}], " ", "-", " ", 
      RowBox[{"2", " ", 
       RowBox[{"H", "[", "a", "]"}], " ", "T", " ", 
       RowBox[{"H", "[", "a", "]"}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{"H", "[", "a", "]"}], " ", "T"}]}], ")"}]}]}]}]], "Equation",
 CellChangeTimes->{
  3.515290798495768*^9, {3.515290843063352*^9, 3.515290920748766*^9}, {
   3.5152910632376337`*^9, 3.5152911167103777`*^9}, {3.515291251174217*^9, 
   3.5152912782133503`*^9}, {3.5152918965193567`*^9, 
   3.515291898302302*^9}},ExpressionUUID->"78f2202f-69ef-4f75-9556-\
2a4c2bb6bc3a"],

Cell["\<\
By using the Jacobi HO basis representation this translates into a matrix \
evolution equation\
\>", "Item",
 CellChangeTimes->{{3.5152911423687*^9, 
  3.515291173967288*^9}},ExpressionUUID->"442b3c8e-f7b6-49ef-82af-\
5fcac5f8ac6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["d", "da"], 
   RowBox[{"HMat", "[", "a", "]"}]}], " ", "=", " ", "\[IndentingNewLine]", 
  RowBox[{"=", 
   RowBox[{
    SuperscriptBox["MN", "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TMat", ".", 
       RowBox[{"HMat", "[", "a", "]"}], ".", 
       RowBox[{"HMat", "[", "a", "]"}]}], " ", "-", " ", 
      RowBox[{"2", " ", 
       RowBox[{
        RowBox[{"HMat", "[", "a", "]"}], ".", "TMat", ".", 
        RowBox[{"HMat", "[", "a", "]"}]}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"HMat", "[", "a", "]"}], ".", 
       RowBox[{"HMat", "[", "a", "]"}], ".", "TMat"}]}], 
     ")"}]}]}]}]], "Equation",
 CellChangeTimes->{
  3.515290798495768*^9, {3.515290843063352*^9, 3.515290920748766*^9}, {
   3.5152910632376337`*^9, 3.5152911167103777`*^9}, {3.5152911907863894`*^9, 
   3.515291244667391*^9}, 3.515291282613371*^9, {3.515291884063099*^9, 
   3.515291892526083*^9}},ExpressionUUID->"4fbddb5b-e95b-4ef8-8ddb-\
4ac1e666e020"],

Cell["\<\
We can solve this matrix evolution equation using the simplest possible \
algorithm for treating ordinary differential equations numerically, the \
so-called Euler algorithm. It is derived by simply replacing the derivative \
on the left-hand-side by a finite difference approximation for a small step \
aDel\
\>", "Item",
 CellChangeTimes->{{3.515291308018732*^9, 3.515291457039742*^9}, {
   3.515303575309176*^9, 3.5153035814923077`*^9}, 
   3.706975308481402*^9},ExpressionUUID->"34f075d8-f0da-42de-b2ad-\
f945be65e77d"],

Cell[BoxData[
 RowBox[{
  FractionBox["d", "da"], 
  RowBox[{
   RowBox[{"HMat", "[", "a", "]"}], " ", "\[LongRightArrow]", "  ", 
   FractionBox["1", "aDel"]}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"HMat", "[", 
     RowBox[{"a", "+", "aDel"}], "]"}], " ", "-", " ", 
    RowBox[{"HMat", "[", "a", "]"}]}], ")"}]}]], "Equation",
 CellChangeTimes->{{3.515291493512306*^9, 3.515291521373364*^9}, 
   3.515307117457649*^9},ExpressionUUID->"1d752d25-089c-46de-8d82-\
9cbd053d300d"],

Cell["\<\
After some simple algebra we obtain the following explicit equation, which \
gives the matrix HMat for flow parameter a+aDel based on the matrices TMat \
and HMat at flow parameter a, i.e., it brings us one step further in the flow \
parameter a. \
\>", "Item",
 CellChangeTimes->{{3.515291539440487*^9, 3.51529154051618*^9}, {
  3.515291577228812*^9, 3.515291577731328*^9}, {3.5152916170017548`*^9, 
  3.5152917172839937`*^9}, {3.5153037014958344`*^9, 3.515303719855541*^9}, {
  3.706974542011368*^9, 
  3.7069745427155952`*^9}},ExpressionUUID->"51dfba7d-56ed-4869-b0cb-\
09d32f8b2398"],

Cell[BoxData[
 RowBox[{
  RowBox[{"HMat", "[", 
   RowBox[{"a", " ", "+", " ", "aDel"}], "]"}], " ", "=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"=", 
   RowBox[{
    RowBox[{"HMat", "[", "a", "]"}], " ", "+", " ", 
    RowBox[{"aDel", " ", 
     SuperscriptBox["MN", "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"TMat", ".", 
        RowBox[{"HMat", "[", "a", "]"}], ".", 
        RowBox[{"HMat", "[", "a", "]"}]}], " ", "-", " ", 
       RowBox[{"2", " ", 
        RowBox[{
         RowBox[{"HMat", "[", "a", "]"}], ".", "TMat", ".", 
         RowBox[{"HMat", "[", "a", "]"}]}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"HMat", "[", "a", "]"}], ".", 
        RowBox[{"HMat", "[", "a", "]"}], ".", "TMat"}]}], 
      ")"}]}]}]}]}]], "Equation",
 CellChangeTimes->{
  3.515290798495768*^9, {3.515290843063352*^9, 3.515290920748766*^9}, {
   3.5152910632376337`*^9, 3.5152911167103777`*^9}, {3.5152911907863894`*^9, 
   3.515291244667391*^9}, 3.515291282613371*^9, {3.515291588676566*^9, 
   3.515291610051304*^9}, {3.515291905806964*^9, 
   3.515291910438715*^9}},ExpressionUUID->"d13a6625-054b-4731-bd2e-\
327f2c26a641"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Subsection",
 CellChangeTimes->{{3.515291738568768*^9, 
  3.5152917496097927`*^9}},ExpressionUUID->"d05b4532-96a2-4111-add1-\
9901772a1145"],

Cell["\<\
We implement the Euler-type evolution directly. We set a small step size aDel \
and prepare the initial Hamiltonian matrix, given by the sum of the kinetic \
energy matrix and the interaction matrix.\
\>", "Item",
 CellChangeTimes->{{3.515291776801811*^9, 3.515291856492342*^9}, {
  3.51529204296596*^9, 
  3.51529205075663*^9}},ExpressionUUID->"550d2cad-3daa-4bd7-aa25-\
5045e5c6885f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", " ", "=", " ", "0.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aDel", " ", "=", " ", "0.0001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HMat", " ", "=", " ", 
   RowBox[{"TMat", " ", "+", " ", "VMat"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.515243652400633*^9, 3.515243676573627*^9}, 
   3.515258005528977*^9, {3.515291865629594*^9, 3.5152918663903027`*^9}, {
   3.5152922853238983`*^9, 3.515292288961193*^9}, {3.515293244776339*^9, 
   3.5152932450168533`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"786e6f9a-fbc9-438b-b71a-90813944c698"],

Cell["\<\
For storing the SRG-evolved interaction matrix elements, we use a set of \
variables VMatSRG[a], where a is the numerical value of the flow-parameter\
\>", "Item",
 CellChangeTimes->{{3.51529765108854*^9, 3.5152976587708187`*^9}, {
  3.515297791707727*^9, 3.515297850330145*^9}, {3.515303814620173*^9, 
  3.515303827347044*^9}},ExpressionUUID->"45adc26e-00c0-4692-9836-\
20b1a73a7d9f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "VMatSRG", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"VMatSRG", "[", "0.0", "]"}], " ", "=", " ", "VMat"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.515293358044388*^9, 3.5152933699202967`*^9}, {
  3.515297629284136*^9, 3.5152976400512114`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"60a17881-4351-45cf-9fe0-2993b4cbffee"],

Cell["\<\
We evaluate a single step of the Euler algorithm according to the above \
equation (4). Since the step size aDel has to be very small in order to make \
the algorithm work, we have to do many steps to evolve the matrices to \
sizable flow-parameters a. Therefore, we always do 500 evolution steps in a \
row using a simple Do-loop. The evaluation of this little program takes some \
time...\
\>", "Item",
 CellChangeTimes->{{3.515258420513083*^9, 3.515258495034589*^9}, {
   3.515291983415262*^9, 3.515292215164777*^9}, {3.51529232063083*^9, 
   3.515292337845689*^9}, {3.515293253920045*^9, 3.5152932593497047`*^9}, {
   3.5153038803761463`*^9, 3.515303881702373*^9}, 
   3.706974554586195*^9},ExpressionUUID->"8431c8c0-203b-46b6-b49f-\
a194d58b036d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Do", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"HMatDel", " ", "=", " ", 
       RowBox[{"aDel", " ", 
        RowBox[{"MN", "^", "2"}], " ", 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{"TMat", ".", "HMat", ".", "HMat"}], " ", "-", " ", 
          RowBox[{"2", " ", 
           RowBox[{"HMat", ".", "TMat", ".", "HMat"}]}], " ", "+", " ", 
          RowBox[{"HMat", ".", "HMat", ".", "TMat"}]}], " ", ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"HMat", " ", "=", " ", 
       RowBox[{"HMat", " ", "+", " ", "HMatDel"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"a", "+", "aDel"}]}], ";"}], "\[IndentingNewLine]", ",", 
     RowBox[{"{", "500", "}"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", " ", "=", " ", 
   RowBox[{"Round", "[", 
    RowBox[{"a", ",", "0.00001"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"VMatSRG", "[", "a", "]"}], " ", "=", " ", 
    RowBox[{"HMat", "-", "TMat"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Evolution up to a=\>\"", "<>", 
    RowBox[{"ToString", "[", "a", "]"}], "<>", "\"\< completed.\>\""}], "]"}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.515243614883772*^9, 3.515243640578217*^9}, 
   3.515243681793483*^9, {3.5152442971375237`*^9, 3.515244330561859*^9}, {
   3.51524437914135*^9, 3.515244405460823*^9}, 3.515244439304*^9, {
   3.515291948780408*^9, 3.515291971162917*^9}, {3.515292301290205*^9, 
   3.515292306097947*^9}, {3.515293249417152*^9, 3.515293312826756*^9}, {
   3.515293651408268*^9, 3.5152936581831627`*^9}, {3.5152982688816843`*^9, 
   3.515298279808611*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"ff92846d-77eb-4ebf-8706-71e07d301975"],

Cell["\<\
Note that this code just continues the evolution from the latest values of \
the variables HMat and a. Thus, if you evaluate the cell a second or third \
time, you will continue the evolution to larger a. The intermediate results \
for the evolved interaction matrix elements are stored in the variables \
VMatSRG[0.05], VMatSRG[0.1],... Make sure that you evaluate the above cell at \
least twice!\
\>", "Item",
 CellChangeTimes->{{3.51529380202337*^9, 3.515293930991371*^9}, {
  3.515297573819682*^9, 3.5152976214107037`*^9}, {3.5152985011221247`*^9, 
  3.5152985138022957`*^9}},ExpressionUUID->"2fffd5dd-01c4-4b63-aaaf-\
b8ae735f4b08"],

Cell["\<\
We can create plots of the initial interaction matrix elements and the \
evolved ones for direct comparison. What do you observe?\
\>", "Item",
 CellChangeTimes->{{3.515297877231317*^9, 
  3.515297934486864*^9}},ExpressionUUID->"49b88883-4f69-4bda-85da-\
c872929a0e7e"],

Cell[BoxData[{
 RowBox[{"ArrayPlot", "[", " ", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"VMatSRG", "[", "0.0", "]"}], "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "3"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ArrayPlot", "[", " ", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"VMatSRG", "[", "0.05", "]"}], "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "3"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ArrayPlot", "[", " ", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"VMatSRG", "[", "0.1", "]"}], "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "3"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5152436952300043`*^9, 3.515243728309512*^9}, 
   3.515244632074003*^9, {3.5152580620361958`*^9, 3.515258062267926*^9}, 
   3.5152923479110947`*^9, {3.5152934910067997`*^9, 3.515293522467621*^9}, {
   3.5152937797543697`*^9, 3.5152937856482973`*^9}, {3.515297940202238*^9, 
   3.5152979453365726`*^9}, {3.515298408552985*^9, 3.5152984109351797`*^9}, {
   3.515298488388762*^9, 3.515298494460821*^9}, {3.515298529315578*^9, 
   3.515298532033619*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"968c2702-58e3-4054-88ee-bbbef4201046"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["No-Core Shell Model", "Section",
 CellChangeTimes->{{3.515258610597291*^9, 3.515258611855206*^9}, {
  3.5153001853730183`*^9, 
  3.515300190648841*^9}},ExpressionUUID->"09c84cc8-8417-448c-9780-\
e98be5639081"],

Cell["\<\
Finally, we can solve the exact Schr\[ODoubleDot]dinger equation for the \
triton via a matrix eigenvalue problem, which corresponds to a full-fledged \
No-Core Shell Model calculation.\
\>", "Item",
 CellChangeTimes->{{3.515297973163558*^9, 3.515298062378296*^9}, {
  3.515304429493759*^9, 3.515304437964479*^9}, {3.645835696331317*^9, 
  3.645835707906747*^9}},ExpressionUUID->"e9107dc9-c1c5-442f-9174-\
17490b62da91"],

Cell[CellGroupData[{

Cell["Implementation", "Subsection",
 CellChangeTimes->{{3.645433266509923*^9, 
  3.645433272688533*^9}},ExpressionUUID->"8cb84a52-1740-46e6-b6ca-\
62972f70263d"],

Cell["\<\
In Mathematica this is essentially a one-line program once we have the \
Hamiltonian matrix elements available. We use the command Eigenvalues[] to \
obtain the 5 eigenvalues of lowest magnitude and select the smallest one from \
these, since we are only interested in the ground state. \
\>", "Item",
 CellChangeTimes->{{3.51529806602794*^9, 3.515298195229495*^9}, 
   3.7069753503523417`*^9},ExpressionUUID->"c9997a14-5078-43c9-a7c9-\
9f723ad11d01"],

Cell["For the initial Hamiltonian we get", "Item",
 CellChangeTimes->{{3.5152983535522757`*^9, 
  3.515298369678898*^9}},ExpressionUUID->"fbbbb3fb-1d8b-4073-bd90-\
5c63af84a0d9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"HMat", " ", "=", " ", 
   RowBox[{"TMat", " ", "+", " ", 
    RowBox[{"VMatSRG", "[", "0.0", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Min", "[", 
  RowBox[{"Eigenvalues", "[", 
   RowBox[{"HMat", ",", " ", 
    RowBox[{"-", "5"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5152415646019297`*^9, 3.515241613487144*^9}, {
   3.515298201670476*^9, 3.5152982244464006`*^9}, 3.515298440712447*^9},
 CellLabel->"In[32]:=",ExpressionUUID->"6b4b770a-ea72-4916-8a50-232ecac0adbf"],

Cell["For the SRG-evolved Hamiltonian we get for a=0.05", "Item",
 CellChangeTimes->{{3.5152983535522757`*^9, 3.515298369678898*^9}, {
  3.515298468043757*^9, 
  3.515298477466776*^9}},ExpressionUUID->"50bc60f1-e981-4167-a72e-\
8e9a7aba3526"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"HMat", " ", "=", " ", 
   RowBox[{"TMat", " ", "+", " ", 
    RowBox[{"VMatSRG", "[", "0.05", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Min", "[", 
  RowBox[{"Eigenvalues", "[", 
   RowBox[{"HMat", ",", " ", 
    RowBox[{"-", "5"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5152415646019297`*^9, 3.515241613487144*^9}, {
   3.515298201670476*^9, 3.5152982244464006`*^9}, 3.515298384872614*^9, 
   3.51529844579025*^9},
 CellLabel->"In[34]:=",ExpressionUUID->"8b6c7f56-47e6-4c91-b593-7e43d4ffb4d7"],

Cell["For the SRG-evolved Hamiltonian we get for a=0.1", "Item",
 CellChangeTimes->{{3.5152983535522757`*^9, 3.515298369678898*^9}, {
  3.515298468043757*^9, 3.515298477466776*^9}, {3.5152986120560427`*^9, 
  3.515298614237767*^9}},ExpressionUUID->"a37772c5-665b-4519-95f2-\
8e966a29f55b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"HMat", " ", "=", " ", 
   RowBox[{"TMat", " ", "+", " ", 
    RowBox[{"VMatSRG", "[", "0.1", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Min", "[", 
  RowBox[{"Eigenvalues", "[", 
   RowBox[{"HMat", ",", " ", 
    RowBox[{"-", "5"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5152415646019297`*^9, 3.515241613487144*^9}, {
   3.515298201670476*^9, 3.5152982244464006`*^9}, 3.515298384872614*^9, 
   3.51529844579025*^9, {3.515298624704328*^9, 3.515298624999797*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"6bcf4173-5600-47f4-a83f-d9a37fcf3fab"],

Cell["\<\
The eigenvalues we obtain are almost the same for all three Hamiltonians, \
which is due to the unitarity of the transformation. Do you have any idea why \
they are not exactly the same?\
\>", "Item",
 CellChangeTimes->{{3.515298456017119*^9, 3.515298461493107*^9}, {
  3.515298559424149*^9, 3.5152985860647984`*^9}, {3.5152986822126703`*^9, 
  3.515298740688027*^9}, {3.515304104113143*^9, 
  3.515304124636859*^9}},ExpressionUUID->"d6ea0a0d-b448-4015-b3f0-\
d8df67653c35"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Convergence", "Subsection",
 CellChangeTimes->{{3.5152986385650663`*^9, 
  3.5152986413980722`*^9}},ExpressionUUID->"b344f88c-968a-4a80-9b0c-\
c88aaa25d572"],

Cell[TextData[{
 "We can also look at the convergence behavior of the different Hamiltonians. \
In order to do so, we extract from the full Hamiltonian matrix a sequence of \
submatrices that correspond to the different ",
 Cell[BoxData[
  FormBox["NMax", TraditionalForm]],ExpressionUUID->
  "789648ba-73be-4339-8028-f9dec9640ae5"],
 "-truncated model spaces for NMax=2,...,20. For this we need the sizes of \
the submatrices corresponding to the different NMax-truncated spaces, which \
are given in the following cell:"
}], "Item",
 CellChangeTimes->{{3.515298758820129*^9, 3.515298922424849*^9}, {
  3.515299597477363*^9, 3.515299646007142*^9}, {3.515304145066992*^9, 
  3.515304155097934*^9}, {3.515304260526232*^9, 
  3.515304260910448*^9}},ExpressionUUID->"1149c637-61cb-4738-a61e-\
64a9161858bb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NMaxList", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "4", ",", "6", ",", "8", ",", "10", ",", "12", ",", "14", ",", 
     "16", ",", "18", ",", "20"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DimList", " ", "=", 
   RowBox[{"{", 
    RowBox[{
    "5", ",", "15", ",", "34", ",", "64", ",", "108", ",", "169", ",", "249", 
     ",", "351", ",", "478", ",", "632"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.515299089685158*^9, 3.515299129399845*^9}, {
  3.515299326986052*^9, 3.5152993287678137`*^9}, {3.515299396832621*^9, 
  3.5152994052467813`*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"23a10dfa-2484-4296-aa5b-e858acf0ba3c"],

Cell["\<\
Now we can extract a sequence of submatrices and solve the eigenvalue problem \
for each of them. This gives us the ground-state energies for the triton for \
a sequence of NMax values, which are returned by the following cell as a list \
with entries {NMax, EE0}. We start with the initial Hamiltonian:\
\>", "Item",
 CellChangeTimes->{{3.515299654929203*^9, 3.515299755742922*^9}, {
  3.51530426664624*^9, 
  3.515304302275489*^9}},ExpressionUUID->"8a7be400-0e0f-4e40-8813-\
ec02b84e3564"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EEList", "[", "0.0", "]"}], " ", "=", " ", 
  RowBox[{"Table", "[", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"HMat", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{
        RowBox[{"TMat", " ", "+", " ", 
         RowBox[{"VMatSRG", "[", "0.0", "]"}]}], ",", " ", 
        RowBox[{"DimList", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
        RowBox[{"DimList", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"EE0", " ", "=", "  ", 
      RowBox[{"Min", "[", 
       RowBox[{"Eigenvalues", "[", 
        RowBox[{"HMat", ",", 
         RowBox[{"-", "5"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"NMaxList", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", " ", "EE0"}], "}"}]}], ",", " ", 
    
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "NMaxList", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.515299135110697*^9, 3.5152992384527473`*^9}, 
   3.515299302607692*^9, {3.515299366310644*^9, 3.515299437690628*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"70b1c21d-0bf4-4cb0-a350-3e8b81435ea9"],

Cell["And now we do the same for the SRG-evolved Hamiltonians", "Item",
 CellChangeTimes->{{3.5152997589417458`*^9, 
  3.515299786156283*^9}},ExpressionUUID->"864b60dc-387c-4f8a-889b-\
5a563f728067"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EEList", "[", "0.05", "]"}], " ", "=", " ", 
  RowBox[{"Table", "[", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"HMat", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{
        RowBox[{"TMat", " ", "+", " ", 
         RowBox[{"VMatSRG", "[", "0.05", "]"}]}], ",", " ", 
        RowBox[{"DimList", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
        RowBox[{"DimList", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"EE0", " ", "=", "  ", 
      RowBox[{"Min", "[", 
       RowBox[{"Eigenvalues", "[", 
        RowBox[{"HMat", ",", 
         RowBox[{"-", "5"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"NMaxList", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", " ", "EE0"}], "}"}]}], ",", " ", 
    
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "NMaxList", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.515299135110697*^9, 3.5152992384527473`*^9}, 
   3.515299302607692*^9, {3.515299366310644*^9, 3.5152994514176207`*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"9a41d795-bc2b-4cb1-8e6f-41a052c6e5aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EEList", "[", "0.1", "]"}], " ", "=", " ", 
  RowBox[{"Table", "[", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"HMat", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{
        RowBox[{"TMat", " ", "+", " ", 
         RowBox[{"VMatSRG", "[", "0.1", "]"}]}], ",", " ", 
        RowBox[{"DimList", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
        RowBox[{"DimList", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"EE0", " ", "=", "  ", 
      RowBox[{"Min", "[", 
       RowBox[{"Eigenvalues", "[", 
        RowBox[{"HMat", ",", 
         RowBox[{"-", "5"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"NMaxList", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", " ", "EE0"}], "}"}]}], ",", " ", 
    
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "NMaxList", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.515299135110697*^9, 3.5152992384527473`*^9}, 
   3.515299302607692*^9, {3.515299366310644*^9, 3.515299469988451*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"89a69005-83e4-4970-9eb7-0c59648d17ed"],

Cell["\<\
We can visualize the results in a combined convergence plot for the three \
Hamiltonians, showing the ground-state energies as function of NMax. This is \
the type of plot that was shown in the lecture as well. What do you observe?\
\>", "Item",
 CellChangeTimes->{{3.51529978992201*^9, 3.515299862842795*^9}, {
  3.515304323238854*^9, 
  3.5153043304548693`*^9}},ExpressionUUID->"840a16d7-693a-4b32-ae1a-\
1e370522c6ee"],

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"EEList", "[", "0.0", "]"}], ",", 
    RowBox[{"EEList", "[", "0.05", "]"}], ",", 
    RowBox[{"EEList", "[", "0.1", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.515299473301049*^9, 3.515299513344323*^9}, 
   3.515299567529647*^9},
 CellLabel->"In[43]:=",ExpressionUUID->"cf2de384-562b-4d6b-a801-b4583d5d5bde"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Next Steps", "Section",
 CellChangeTimes->{{3.515299923690662*^9, 3.5152999590387707`*^9}, {
  3.706864604451479*^9, 3.706864607621324*^9}, {3.7069751708415537`*^9, 
  3.706975173302642*^9}},ExpressionUUID->"7273fb08-3ecb-4612-b7eb-\
afa453c5c5fc"],

Cell[CellGroupData[{

Cell["Fundamentals", "Subsection",
 CellChangeTimes->{{3.7068654927304363`*^9, 
  3.7068654946697893`*^9}},ExpressionUUID->"89a43de3-c270-46ad-84ad-\
d6b21683d651"],

Cell["\<\
Implement the above SRG transformation and the NCSM solution in a programming \
language of your choice. You can copy/adapt this Mathematica implementation, \
but then make sure that you understand each and every line. \
\>", "Item",
 CellChangeTimes->{{3.51529996558914*^9, 3.515300032892764*^9}, {
   3.515304346957369*^9, 3.5153043716991253`*^9}, 3.515307313377927*^9, {
   3.645433781610835*^9, 3.645433832414946*^9}, {3.645433958541074*^9, 
   3.645433961341776*^9}, 3.645434021259368*^9, {3.706864641201757*^9, 
   3.706864700710909*^9}, {3.706871926763877*^9, 3.7068719769992228`*^9}, {
   3.823508857056287*^9, 3.823508871531377*^9}, {3.823508921131095*^9, 
   3.823508927310627*^9}},ExpressionUUID->"5a344df8-dd61-4270-b2d0-\
d8e81a7442f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Algorithms", "Subsection",
 CellChangeTimes->{{3.7068654448266363`*^9, 
  3.706865450525475*^9}},ExpressionUUID->"ba6497ea-09e5-4611-8c2c-\
ec56a430e499"],

Cell["\<\
Replace the simplistic Euler approach for solving the SRG initial-value \
problem with a more sophisticated ODE solver. How can you check the numerical \
accuracy of the numerical algorithm?  \
\>", "Item",
 CellChangeTimes->{{3.51529996558914*^9, 3.515300032892764*^9}, {
   3.515304346957369*^9, 3.5153043716991253`*^9}, 3.515307313377927*^9, {
   3.645433781610835*^9, 3.645433832414946*^9}, {3.645433958541074*^9, 
   3.645433961341776*^9}, 3.645434021259368*^9, {3.706864717035651*^9, 
   3.706864736863452*^9}, {3.706865186965827*^9, 3.706865193148348*^9}, {
   3.706865230020834*^9, 3.706865345198402*^9}, {3.706865542990028*^9, 
   3.706865580302988*^9}, {3.706865639926775*^9, 
   3.70686577903091*^9}},ExpressionUUID->"69db1212-7db6-4c8b-93d6-\
9d467dd802fc"],

Cell["\<\
Implement the Lanczos algorithm for solving the eigenvalue problem and \
explore its properties, particularly, the convergence of eigenvalues with the \
number of iterations and the possible loss of orthogonality due to round-off \
errors.   \
\>", "Item",
 CellChangeTimes->{{3.645433963863277*^9, 3.645433972844253*^9}, {
  3.6454340245436*^9, 3.6454340278738117`*^9}, {3.706865377405274*^9, 
  3.7068654377342243`*^9}, {3.706865786525172*^9, 3.7068658484642067`*^9}, {
  3.706865922584306*^9, 
  3.7068659537835693`*^9}},ExpressionUUID->"4527b5ec-2f2d-43c5-b326-\
92164ccaa9b6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Physics", "Subsection",
 CellChangeTimes->{{3.706865458464984*^9, 
  3.706865465833345*^9}},ExpressionUUID->"6ef4184d-5eb0-449f-9cbb-\
e20d06343312"],

Cell["\<\
Plot the ground state energy of the triton for different Nmax (e.g. \
Nmax=0,10,20) as function of the SRG flow parameter. Interpret your result.\
\>", "Item",
 CellChangeTimes->{{3.645433963863277*^9, 3.645433972844253*^9}, {
  3.6454340245436*^9, 3.6454340278738117`*^9}, {3.64543406443712*^9, 
  3.6454341866008663`*^9}, {3.706866982411955*^9, 3.7068670312801237`*^9}, {
  3.706867101006648*^9, 
  3.706867212813986*^9}},ExpressionUUID->"5f77f7ec-3099-484c-9113-\
42d5debb9873"],

Cell["\<\
Play with the SRG evolution and study, e.g., what happens for larger flow \
parameters or what changes if you reverse the direction of the flow. \
\>", "Item",
 CellChangeTimes->{{3.706865985457759*^9, 
  3.70686601404486*^9}},ExpressionUUID->"a35f6ffc-00e1-457c-a1e6-\
156c83c40e51"],

Cell["Invent and test new generators for the SRG evolution.", "Item",
 CellChangeTimes->{{3.645433963863277*^9, 3.645433972844253*^9}, {
  3.6454340245436*^9, 3.6454340278738117`*^9}, {3.64543406443712*^9, 
  3.6454340952390337`*^9}, {3.706866019212295*^9, 
  3.706866021996283*^9}},ExpressionUUID->"af511de2-960b-4cfb-9dd6-\
4c1a575ebf94"]
}, Open  ]]
}, Closed]]
},
WindowToolbars->{},
WindowSize->{1176, 904},
WindowMargins->{{641, Automatic}, {Automatic, 89}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[
     ValueBox["FileName"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}, {
   Cell[
    TextData[
     ValueBox["FileName"]], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}},
PageFooters->{{
   Cell[
    TextData[
     ValueBox["Date"]], "Footer", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, None}, {
  None, None, None}},
PageHeaderLines->{True, True},
PageFooterLines->{False, False},
PrintingOptions->{"FacingPages"->False,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->True,
"PaperOrientation"->"Portrait",
"PaperSize"->{595, 842}},
ShowCellLabel->False,
SpellingDictionaries->{"CorrectWords"->{"Hamiltonians"}},
FrontEndVersion->"12.2 for Mac OS X x86 (64-bit) (December 12, 2020)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions", "Subtitle"], 
      Cell[
      "Modify the definitions below to change the default appearance of all \
cells in a given style.  Make modifications to any definition using commands \
in the Format menu.", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section"], 
         Cell[
          StyleData[All, "Working"], PageWidth :> WindowWidth, ScriptMinSize -> 
          9], 
         Cell[
          StyleData[All, "Printout"], PageWidth :> PaperWidth, ScriptMinSize -> 
          7, FontSize -> 10, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section"], 
         Cell[
         "The options defined for the style below will be used at the \
Notebook level.", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"]}, {
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, PageFooters -> {{
             Cell[
              TextData[{
                ValueBox["Date"]}], "Footer"], None, None}, {None, None, 
             Cell[
              TextData[{
                ValueBox["Date"]}], "Footer"]}}, 
          CellBracketOptions -> {"Color" -> RGBColor[0, 0, 0.466667]}, 
          StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Header Graphic (to be pasted in)", "Section"], 
         Cell[
          StyleData["HeaderCell"], ShowCellBracket -> False, 
          CellMargins -> {{0, 0}, {0, 0}}, Evaluatable -> False, 
          PageBreakBelow -> False, ImageSize -> {1, 1}, 
          ImageMargins -> {{0, 0}, {0, 0}}, ImageRegion -> {{0, 1}, {0, 1}}, 
          StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1, 0}, 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Times", FontSize -> 36, 
             FontWeight -> "Plain", FontSlant -> "Italic", 
             FontVariations -> {
              "Outline" -> False, "Shadow" -> False, "Underline" -> False}, 
             FontColor -> GrayLevel[1], Background -> 
             RGBColor[0.299992, 0.299992, 0.699992]], 
            Cell[
             StyleData["Title", "Printout"], CellMargins -> {{0, 0}, {0, 0}}, 
             FontSize -> 24]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1.1, 0}, 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Times", FontSize -> 22, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[1], Background -> 
             RGBColor[0.450004, 0.450004, 0.900008]], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{0, 0}, {0, 0}}, FontSize -> 16]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1.1, 0}, 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Times", FontSize -> 18, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[1], Background -> RGBColor[0.549996, 0.549996, 1]], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{0, 0}, {0, 0}}, FontSize -> 12]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> {{0, 0}, {0, 2}}, CellDingbat -> 
             None, CellMargins -> {{10, 5}, {10, 35}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameMargins -> {{5, 0}, {4, 7}}, CellFrameColor -> 
             RGBColor[0.299992, 0.299992, 0.699992], LineSpacing -> {0, 22}, 
             CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
               "Exercise", 0}}, FontFamily -> "Helvetica", FontSize -> 24, 
             FontWeight -> "Plain", FontSlant -> "Plain", FontTracking -> 
             "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Outline" -> False, "Shadow" -> False,
                "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             GrayLevel[0], Background -> 
             RGBColor[0.970779, 0.898436, 0.686671], 
             FontVariations -> {"Masked" -> False}, 
             FontVariations -> {"RotationAngle" -> 0}], 
            Cell[
             StyleData["Section", "Printout"], CellFrame -> {{0, 0}, {0, 1}}, 
             CellMargins -> {{0, 5}, {8, 20}}, 
             CellFrameMargins -> {{5, 0}, {2, 2}}, FontSize -> 18]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellFrame -> False, CellDingbat -> 
             "\[FilledSmallSquare] ", CellMargins -> {{32, 0}, {4, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CellFrameMargins -> {{0, 0}, {0, 2}}, CellFrameColor -> 
             RGBColor[0.2, 0.700008, 0.700008], CounterIncrements -> 
             "Subsection", CounterAssignments -> {{"Subsubsection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 18, FontWeight -> "Bold", 
             FontSlant -> "Plain", FontTracking -> "Plain", 
             FontVariations -> {
              "Outline" -> False, "Shadow" -> False, "Underline" -> False}, 
             FontColor -> RGBColor[0.299992, 0.299992, 0.699992]], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{20, 0}, {8, 20}}, FontSize -> 14, FontWeight -> 
             "Plain"]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellFrame -> False, CellDingbat -> 
             "\[FilledSmallSquare] ", 
             CellMargins -> {{45, Inherited}, {2, 8}}, Evaluatable -> False, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CellFrameMargins -> {{0, 0}, {0, 2}}, CounterIncrements -> 
             "Subsubsection", FontFamily -> "Helvetica", FontSize -> 14, 
             FontWeight -> "Bold", FontSlant -> "Plain", FontTracking -> 
             "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Outline" -> False, "Shadow" -> False,
                "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             RGBColor[0.299992, 0.299992, 0.699992], 
             FontVariations -> {"Masked" -> False}, 
             FontVariations -> {"RotationAngle" -> 0}], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{38, 0}, {6, 15}}, FontSize -> 12, FontWeight -> 
             "Plain"]}, Open]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Body Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{55, 20}, {4, 6}}, 
             LineSpacing -> {1.1, 0}, ParagraphSpacing -> {0, 0}, FontFamily -> 
             "Helvetica", FontSize -> 12, FontWeight -> "Bold", FontSlant -> 
             "Plain", FontTracking -> "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Outline" -> False, "Shadow" -> False,
                "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             GrayLevel[0], FontVariations -> {"Masked" -> False}, 
             FontVariations -> {"RotationAngle" -> 0}], 
            Cell[
             StyleData["Text", "Printout"], PageWidth :> PaperWidth, 
             CellMargins -> {{38, 0}, {3, 5}}, LineSpacing -> {1.2, 0}, 
             FontSize -> 11, FontWeight -> "Plain"]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item"], CellDingbat -> "\[FilledSmallCircle] ", 
             CellMargins -> {{55, 20}, {4, 6}}, LineSpacing -> {1.1, 0}, 
             ParagraphSpacing -> {0, 0}, FontFamily -> "Helvetica", FontSize -> 
             12, FontWeight -> "Bold", FontSlant -> "Plain", FontTracking -> 
             "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Outline" -> False, "Shadow" -> False,
                "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             GrayLevel[0], FontVariations -> {"Masked" -> False}, 
             FontVariations -> {"RotationAngle" -> 0}], 
            Cell[
             StyleData["Item", "Printout"], PageWidth :> PaperWidth, 
             CellMargins -> {{38, 0}, {3, 5}}, LineSpacing -> {1.2, 0}, 
             FontSize -> 11, FontWeight -> "Plain"]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem"], CellDingbat -> "\[EmptySmallSquare]", 
             CellMargins -> {{68, 20}, {4, 6}}, LineSpacing -> {1.1, 0}, 
             ParagraphSpacing -> {0, 0}, FontFamily -> "Helvetica", FontSize -> 
             12, FontWeight -> "Bold", FontSlant -> "Plain", FontTracking -> 
             "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Outline" -> False, "Shadow" -> False,
                "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             GrayLevel[0], FontVariations -> {"Masked" -> False}, 
             FontVariations -> {"RotationAngle" -> 0}], 
            Cell[
             StyleData["Subitem", "Printout"], PageWidth :> PaperWidth, 
             CellMargins -> {{48, 0}, {3, 5}}, LineSpacing -> {1.2, 0}, 
             FontSize -> 11, FontWeight -> "Plain"]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Remark"], CellDingbat -> "\[FilledSmallCircle] ", 
             CellMargins -> {{55, 20}, {4, 6}}, Evaluatable -> False, 
             TextJustification -> 0, LineSpacing -> {1.1, 0}, FontFamily -> 
             "Helvetica", FontSize -> 12, FontWeight -> "Bold", FontSlant -> 
             "Plain", FontTracking -> "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Outline" -> False, "Shadow" -> False,
                "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             RGBColor[0.8, 0, 0], FontVariations -> {"Masked" -> False}, 
             FontVariations -> {"RotationAngle" -> 0}], 
            Cell[
             StyleData["Remark", "Printout"], PageWidth :> PaperWidth, 
             CellMargins -> {{38, 0}, {3, 5}}, LineSpacing -> {1.2, 0}, 
             FontSize -> 11, FontWeight -> "Plain", FontSlant -> "Italic"]}, 
           Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Comment"], CellDingbat -> None, 
             CellMargins -> {{55, 20}, {2, 2}}, Evaluatable -> False, 
             TextJustification -> 0, LineSpacing -> {1.1, 0}, FontFamily -> 
             "Helvetica", FontSize -> 12, FontWeight -> "Plain", FontSlant -> 
             "Plain", FontTracking -> "Plain", 
             FontVariations -> {
              "Outline" -> False, "Shadow" -> False, "Underline" -> False}, 
             FontColor -> GrayLevel[0.6]], 
            Cell[
             StyleData["Comment", "Printout"], PageWidth :> PaperWidth, 
             CellMargins -> {{38, 0}, {3, 5}}, LineSpacing -> {1.2, 0}, 
             FontSize -> 9, FontWeight -> "Plain", FontSlant -> "Plain"]}, 
           Open]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input/Output", "Section"], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellMargins -> {{55, 2}, {5, 5}}, 
             Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
             CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             LineSpacing -> {1, 3}, AutoItalicWords -> {}, FormatType -> 
             InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
             CounterIncrements -> "Input", FontFamily -> "Courier", FontSize -> 
             12, Background -> GrayLevel[0.900008]], 
            Cell[
             StyleData["Input", "Printout"], CellMargins -> {{38, 2}, {2, 2}},
              FontSize -> 10, Background -> GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DeactivatedInput"], PageWidth :> Infinity, 
             CellMargins -> {{63, 20}, {3, 3}}, Evaluatable -> False, 
             CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             LineSpacing -> {1, 3}, AutoItalicWords -> {}, FormatType -> 
             InputForm, ShowStringCharacters -> True, FontFamily -> "Courier",
              FontSize -> 12, FontColor -> GrayLevel[0.450004]], 
            Cell[
             StyleData["DeactivatedInput", "Printout"], PageWidth :> Infinity,
              CellMargins -> {{46, 20}, {5, 5}}, FontSize -> 10]}, Closed]], 
         Cell[
          StyleData["InlineInput"], Evaluatable -> True, CellGroupingRules -> 
          "InputGrouping", CellHorizontalScrolling -> True, PageBreakWithin -> 
          False, GroupPageBreakWithin -> False, DefaultFormatType -> 
          DefaultInputFormatType, "TwoByteSyntaxCharacterAutoReplacement" -> 
          True, HyphenationOptions -> {
           "HyphenationCharacter" -> "\[Continuation]"}, 
          AutoItalicWords -> {}, FormatType -> InputForm, 
          ShowStringCharacters -> True, NumberMarks -> True, 
          CounterIncrements -> "Input", FontWeight -> "Bold"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], PageWidth :> WindowWidth, 
             CellMargins -> {{63, 2}, {10, 5}}, CellEditDuplicate -> True, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             LineSpacing -> {1, 3}, AutoItalicWords -> {}, FormatType -> 
             InputForm, CounterIncrements -> "Output", FontFamily -> 
             "Courier", FontSize -> 12, FontWeight -> "Bold"], 
            Cell[
             StyleData["Output", "Printout"], PageWidth :> PaperWidth, 
             CellMargins -> {{46, 2}, {15, 5}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], CellMargins -> {{55, 20}, {10, 10}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Graphics", 
             ImageSize -> {250, 250}, FontFamily -> "Courier", FontSize -> 
             12], 
            Cell[
             StyleData["Graphics", "Printout"], CellFrame -> False, 
             CellMargins -> {{38, 20}, {10, 10}}, FontSize -> 10]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], CellMargins -> {{63, 20}, {1, 1}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, StyleMenuListing -> None, FontFamily -> "Courier", 
             FontSize -> 10, FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{46, 20}, {1, 1}}, 
             CellLabelMargins -> {{23, Inherited}, {1, 1}}, FontSize -> 6]}, 
           Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], 
             CellMargins -> {{63, 20}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, CellLabelMargins -> {{23, Inherited}, {
               Inherited, Inherited}}, DefaultFormatType -> 
             DefaultOutputFormatType, FormatType -> InputForm, 
             StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
             12], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{46, 20}, {Inherited, Inherited}}, FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Info"], 
             CellMargins -> {{63, 20}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, CellLabelMargins -> {{23, Inherited}, {
               Inherited, Inherited}}, DefaultFormatType -> 
             DefaultOutputFormatType, FormatType -> InputForm, 
             StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
             12], 
            Cell[
             StyleData["Info", "Printout"], 
             CellMargins -> {{46, 20}, {Inherited, Inherited}}, FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Arial", FontSize -> 9, FontTracking -> "Extended", FontColor -> 
             GrayLevel[0.500008]], 
            Cell[
             StyleData["CellLabel", "Printout"], FontSize -> 6, FontSlant -> 
             "Italic", FontColor -> GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Equations and Specials", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Equation"], CellMargins -> {{75, Inherited}, {4, 6}}, 
             CellHorizontalScrolling -> True, CellFrameLabels -> {{None, 
                Cell[
                 TextData[{"(", 
                   CounterBox["Equation"], ")"}]]}, {None, None}}, 
             DefaultFormatType -> TraditionalForm, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> False, 
             SpanMaxSize -> Infinity, CounterIncrements -> "Equation", 
             FontFamily -> "Helvetica", FontSize -> 12, FontWeight -> "Bold", 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}, 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1.}}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["Equation", "Printout"], 
             CellMargins -> {{58, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 10]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["EquationNoNumber"], 
             CellMargins -> {{75, Inherited}, {4, 6}}, 
             CellHorizontalScrolling -> True, DefaultFormatType -> 
             TraditionalForm, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> False, 
             SpanMaxSize -> Infinity, FontFamily -> "Helvetica", FontSize -> 
             12, FontWeight -> "Bold", 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}, 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1.}}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["EquationNoNumber", "Printout"], 
             CellMargins -> {{58, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 10]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Description"], 
             CellMargins -> {{55, Inherited}, {5, 25}}, Evaluatable -> False, 
             CellGroupingRules -> {"SectionGrouping", 50}, 
             LineSpacing -> {1.1, 0}, FontFamily -> "Helvetica", FontSize -> 
             12, FontWeight -> "Bold", FontSlant -> "Plain", FontTracking -> 
             "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Outline" -> False, "Shadow" -> False,
                "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             GrayLevel[0], FontVariations -> {"Masked" -> False}, 
             FontVariations -> {"RotationAngle" -> 0}], 
            Cell[
             StyleData["Description", "Printout"], 
             CellMargins -> {{38, Inherited}, {3, 15}}, 
             LineSpacing -> {1.2, 0}, FontSize -> 12, FontWeight -> "Bold"]}, 
           Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DescriptionCont"], 
             CellMargins -> {{55, Inherited}, {5, 5}}, Evaluatable -> False, 
             CellGroupingRules -> {"SectionGrouping", 50}, 
             LineSpacing -> {1.1, 0}, FontFamily -> "Helvetica", FontSize -> 
             12, FontWeight -> "Bold", FontSlant -> "Plain", FontTracking -> 
             "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Outline" -> False, "Shadow" -> False,
                "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             GrayLevel[0], FontVariations -> {"Masked" -> False}, 
             FontVariations -> {"RotationAngle" -> 0}], 
            Cell[
             StyleData["DescriptionCont", "Printout"], 
             CellMargins -> {{38, Inherited}, {3, 3}}, 
             LineSpacing -> {1.2, 0}, FontSize -> 12, FontWeight -> "Bold"]}, 
           Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Exercise"], CellDingbat -> StyleBox[
               RowBox[{
                 CounterBox["Exercise", CounterFunction -> (Part[
                    CharacterRange["a", "z"], #]& )], ")  "}], FontFamily -> 
               "Helvetica", FontSize -> 12, FontWeight -> "Bold"], 
             CellMargins -> {{55, Inherited}, {5, 25}}, Evaluatable -> False, 
             CellGroupingRules -> {"SectionGrouping", 50}, 
             LineSpacing -> {1.1, 0}, CounterIncrements -> "Exercise", 
             FontFamily -> "Helvetica", FontSize -> 12, FontWeight -> "Bold", 
             FontSlant -> "Plain", FontTracking -> "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Outline" -> False, "Shadow" -> False,
                "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             RGBColor[0.299992, 0.299992, 0.699992], 
             FontVariations -> {"Masked" -> False}, 
             FontVariations -> {"RotationAngle" -> 0}], 
            Cell[
             StyleData["Exercise", "Printout"], 
             CellMargins -> {{22, Inherited}, {3, 15}}, 
             LineSpacing -> {1.2, 0}, FontSize -> 12, FontWeight -> "Bold"]}, 
           Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseCont"], 
             CellMargins -> {{55, Inherited}, {5, 5}}, Evaluatable -> False, 
             CellGroupingRules -> {"SectionGrouping", 50}, 
             LineSpacing -> {1.1, 0}, FontFamily -> "Helvetica", FontSize -> 
             12, FontWeight -> "Bold", FontSlant -> "Plain", FontTracking -> 
             "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Outline" -> False, "Shadow" -> False,
                "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             RGBColor[0.299992, 0.299992, 0.699992], 
             FontVariations -> {"Masked" -> False}, 
             FontVariations -> {"RotationAngle" -> 0}], 
            Cell[
             StyleData["ExerciseCont", "Printout"], 
             CellMargins -> {{38, Inherited}, {3, 3}}, 
             LineSpacing -> {1.2, 0}, FontSize -> 12, FontWeight -> "Bold"]}, 
           Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseNoNumber"], 
             CellMargins -> {{55, Inherited}, {5, 25}}, Evaluatable -> False, 
             CellGroupingRules -> {"SectionGrouping", 50}, 
             LineSpacing -> {1.1, 0}, FontFamily -> "Helvetica", FontSize -> 
             12, FontWeight -> "Bold", FontSlant -> "Plain", FontTracking -> 
             "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Outline" -> False, "Shadow" -> False,
                "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             RGBColor[0.299992, 0.299992, 0.699992], 
             FontVariations -> {"Masked" -> False}, 
             FontVariations -> {"RotationAngle" -> 0}], 
            Cell[
             StyleData["ExerciseNoNumber", "Printout"], 
             CellMargins -> {{38, Inherited}, {3, 15}}, 
             LineSpacing -> {1.2, 0}, FontSize -> 12, FontWeight -> "Bold"]}, 
           Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Conclusion"], CellFrame -> True, 
             CellMargins -> {{55, 10}, {20, 15}}, LineSpacing -> {1.1, 0}, 
             ParagraphSpacing -> {0, 0}, FontFamily -> "Helvetica", FontSize -> 
             12, FontWeight -> "Bold", FontSlant -> "Plain", FontTracking -> 
             "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Outline" -> False, "Shadow" -> False,
                "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             GrayLevel[0], Background -> 
             RGBColor[0.843137, 0.878431, 0.992157], 
             FontVariations -> {"Masked" -> False}, 
             FontVariations -> {"RotationAngle" -> 0}], 
            Cell[
             StyleData["Conclusion", "Printout"], PageWidth :> PaperWidth, 
             CellMargins -> {{38, 0}, {12, 8}}, LineSpacing -> {1.3, 0}, 
             FontSize -> 10, FontWeight -> "Plain"]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Unique Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Supertitle"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             CellFrameMargins -> {{0, 10}, {2, 3}}, TextAlignment -> Right, 
             LineSpacing -> {1.1, 0}, FontFamily -> "Times", FontSize -> 12, 
             FontWeight -> "Plain", FontSlant -> "Plain", FontColor -> 
             GrayLevel[1], Background -> GrayLevel[0]], 
            Cell[
             StyleData["Supertitle", "Printout"], 
             CellMargins -> {{0, 5}, {0, 0}}, FontSize -> 9, FontColor -> 
             GrayLevel[0], Background -> None]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineEmph"], FontSlant -> "Italic", FontColor -> 
             RGBColor[0.8, 0, 0]], 
            Cell[
             StyleData["InlineEmph", "Printout"], FontColor -> GrayLevel[0]]},
            Open]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headers and Footers", "Section"], 
         Cell[
          StyleData["Header"], CellMargins -> {{0, 0}, {1, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Arial", FontSize -> 8, 
          FontWeight -> "Plain", FontSlant -> "Plain", FontTracking -> 
          "Plain", 
          FontVariations -> {
           "CompatibilityType" -> 0, "Outline" -> False, "Shadow" -> False, 
            "StrikeThrough" -> False, "Underline" -> False}, 
          FontVariations -> {"Masked" -> False}, 
          FontVariations -> {"RotationAngle" -> 0}], 
         Cell[
          StyleData["Footer"], CellMargins -> {{0, 0}, {0, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Arial", FontSize -> 8, 
          FontSlant -> "Plain"], 
         Cell[
          StyleData["PageNumber"], CellMargins -> {{0, 0}, {1, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Arial", FontSize -> 10, 
          FontSlant -> "Plain"]}, Closed]]}, Open]]}, 
  WindowSize -> {808, 911}, 
  WindowMargins -> {{68, Automatic}, {Automatic, 164}}, Visible -> False, 
  FrontEndVersion -> "12.2 for Mac OS X x86 (64-bit) (December 12, 2020)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"083c11c1-6cf4-4dbe-b371-5c7e2ee2b2e5"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 155, 3, 52, "Title",ExpressionUUID->"6a616d33-8ac1-49f2-99d6-e5224779036d"],
Cell[703, 25, 271, 7, 65, "Subtitle",ExpressionUUID->"a216c7a2-10b5-4abe-b8da-2459c0bf4b41"],
Cell[CellGroupData[{
Cell[999, 36, 160, 3, 83, "Section",ExpressionUUID->"6b2456ea-3953-43d3-8356-df5168df1ab1"],
Cell[1162, 41, 435, 8, 23, "Item",ExpressionUUID->"3c36995d-931a-4f0b-abd8-86e4a9e962e7"],
Cell[1600, 51, 1172, 30, 81, "Input",ExpressionUUID->"8c245e44-5e1f-47d0-95df-7d248bf90e62"],
Cell[2775, 83, 1181, 26, 100, "Input",ExpressionUUID->"2c0766ee-c797-4dc4-b16d-51fbb7300adc"]
}, Closed]],
Cell[CellGroupData[{
Cell[3993, 114, 213, 4, 52, "Section",ExpressionUUID->"df1c4a51-30b7-49fc-8490-ee29f77d7c5a"],
Cell[4209, 120, 607, 13, 27, "Item",ExpressionUUID->"506d407b-60bd-45a3-adb3-beedd368d66e"],
Cell[4819, 135, 448, 9, 38, "Item",ExpressionUUID->"ae85637c-6196-4434-b611-bada22df0feb"],
Cell[5270, 146, 413, 8, 38, "Item",ExpressionUUID->"5b9e8d04-d3cb-4ec1-8674-313881dc0167"],
Cell[5686, 156, 752, 13, 52, "Item",ExpressionUUID->"dd9d04b2-b0f2-4253-ba61-9949b337c59b"],
Cell[6441, 171, 414, 8, 23, "Item",ExpressionUUID->"8ff113e9-249a-4386-a07f-941c13d0e7b2"],
Cell[6858, 181, 295, 5, 42, "Input",ExpressionUUID->"c4d47fdc-5ad8-471f-bd25-88f9f50d1dfb"],
Cell[7156, 188, 403, 8, 23, "Item",ExpressionUUID->"6c5b0791-fa82-4f6b-aa04-003d9f012999"],
Cell[7562, 198, 526, 12, 62, "Input",ExpressionUUID->"0c9202ec-3464-4111-a9da-2cf836d69710"],
Cell[8091, 212, 480, 9, 38, "Item",ExpressionUUID->"ca2a6205-848a-4166-a31c-56bbe73c1f82"],
Cell[8574, 223, 506, 10, 42, "Input",ExpressionUUID->"f279bb66-2c0f-4cbc-be3b-e7f652300072"],
Cell[9083, 235, 484, 10, 42, "Input",ExpressionUUID->"abd45905-2855-41b7-b162-3be873293cfc"]
}, Closed]],
Cell[CellGroupData[{
Cell[9604, 250, 181, 3, 52, "Section",ExpressionUUID->"8b94ebfe-6512-4e34-bb7b-b7893150f66f"],
Cell[CellGroupData[{
Cell[9810, 257, 171, 3, 43, "Subsection",ExpressionUUID->"c3c1a581-6ce3-4b9f-a8d0-dde689498442"],
Cell[9984, 262, 299, 6, 23, "Item",ExpressionUUID->"53617733-b79f-43a6-b109-85a440a9b6b8"],
Cell[10286, 270, 399, 8, 23, "Item",ExpressionUUID->"3ac2edc5-c568-4862-b3f0-3377de7bb4e5"],
Cell[10688, 280, 1174, 32, 63, "Equation",ExpressionUUID->"78f2202f-69ef-4f75-9556-2a4c2bb6bc3a"],
Cell[11865, 314, 242, 6, 23, "Item",ExpressionUUID->"442b3c8e-f7b6-49ef-82af-5fcac5f8ac6b"],
Cell[12110, 322, 1001, 26, 63, "Equation",ExpressionUUID->"4fbddb5b-e95b-4ef8-8ddb-4ac1e666e020"],
Cell[13114, 350, 533, 10, 38, "Item",ExpressionUUID->"34f075d8-f0da-42de-b2ad-f945be65e77d"],
Cell[13650, 362, 482, 13, 43, "Equation",ExpressionUUID->"1d752d25-089c-46de-8d82-9cbd053d300d"],
Cell[14135, 377, 597, 11, 38, "Item",ExpressionUUID->"51dfba7d-56ed-4869-b0cb-09d32f8b2398"],
Cell[14735, 390, 1144, 29, 47, "Equation",ExpressionUUID->"d13a6625-054b-4731-bd2e-327f2c26a641"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15916, 424, 164, 3, 43, "Subsection",ExpressionUUID->"d05b4532-96a2-4111-add1-9901772a1145"],
Cell[16083, 429, 396, 8, 38, "Item",ExpressionUUID->"550d2cad-3daa-4bd7-aa25-5045e5c6885f"],
Cell[16482, 439, 611, 12, 81, "Input",ExpressionUUID->"786e6f9a-fbc9-438b-b71a-90813944c698"],
Cell[17096, 453, 395, 7, 23, "Item",ExpressionUUID->"45adc26e-00c0-4692-9836-20b1a73a7d9f"],
Cell[17494, 462, 403, 9, 62, "Input",ExpressionUUID->"60a17881-4351-45cf-9fe0-2993b4cbffee"],
Cell[17900, 473, 762, 13, 52, "Item",ExpressionUUID->"8431c8c0-203b-46b6-b49f-a194d58b036d"],
Cell[18665, 488, 1925, 45, 214, "Input",ExpressionUUID->"ff92846d-77eb-4ebf-8706-71e07d301975"],
Cell[20593, 535, 648, 11, 52, "Item",ExpressionUUID->"2fffd5dd-01c4-4b63-aaaf-b8ae735f4b08"],
Cell[21244, 548, 279, 6, 23, "Item",ExpressionUUID->"49b88883-4f69-4bda-85da-c872929a0e7e"],
Cell[21526, 556, 1315, 29, 81, "Input",ExpressionUUID->"968c2702-58e3-4054-88ee-bbbef4201046"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[22890, 591, 215, 4, 52, "Section",ExpressionUUID->"09c84cc8-8417-448c-9780-e98be5639081"],
Cell[23108, 597, 430, 8, 23, "Item",ExpressionUUID->"e9107dc9-c1c5-442f-9174-17490b62da91"],
Cell[CellGroupData[{
Cell[23563, 609, 162, 3, 43, "Subsection",ExpressionUUID->"8cb84a52-1740-46e6-b6ca-62972f70263d"],
Cell[23728, 614, 461, 8, 38, "Item",ExpressionUUID->"c9997a14-5078-43c9-a7c9-9f723ad11d01"],
Cell[24192, 624, 178, 3, 23, "Item",ExpressionUUID->"fbbbb3fb-1d8b-4073-bd90-5c63af84a0d9"],
Cell[24373, 629, 525, 11, 62, "Input",ExpressionUUID->"6b4b770a-ea72-4916-8a50-232ecac0adbf"],
Cell[24901, 642, 242, 4, 23, "Item",ExpressionUUID->"50bc60f1-e981-4167-a72e-8e9a7aba3526"],
Cell[25146, 648, 551, 12, 62, "Input",ExpressionUUID->"8b6c7f56-47e6-4c91-b593-7e43d4ffb4d7"],
Cell[25700, 662, 289, 4, 23, "Item",ExpressionUUID->"a37772c5-665b-4519-95f2-8e966a29f55b"],
Cell[25992, 668, 596, 12, 62, "Input",ExpressionUUID->"6bcf4173-5600-47f4-a83f-d9a37fcf3fab"],
Cell[26591, 682, 484, 9, 23, "Item",ExpressionUUID->"d6ea0a0d-b448-4015-b3f0-d8df67653c35"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27112, 696, 163, 3, 43, "Subsection",ExpressionUUID->"b344f88c-968a-4a80-9b0c-c88aaa25d572"],
Cell[27278, 701, 804, 15, 53, "Item",ExpressionUUID->"1149c637-61cb-4738-a61e-64a9161858bb"],
Cell[28085, 718, 713, 16, 62, "Input",ExpressionUUID->"23a10dfa-2484-4296-aa5b-e858acf0ba3c"],
Cell[28801, 736, 501, 9, 38, "Item",ExpressionUUID->"8a7be400-0e0f-4e40-8813-ec02b84e3564"],
Cell[29305, 747, 1238, 31, 100, "Input",ExpressionUUID->"70b1c21d-0bf4-4cb0-a350-3e8b81435ea9"],
Cell[30546, 780, 199, 3, 23, "Item",ExpressionUUID->"864b60dc-387c-4f8a-889b-5a563f728067"],
Cell[30748, 785, 1242, 31, 100, "Input",ExpressionUUID->"9a41d795-bc2b-4cb1-8e6f-41a052c6e5aa"],
Cell[31993, 818, 1238, 31, 100, "Input",ExpressionUUID->"89a69005-83e4-4970-9eb7-0c59648d17ed"],
Cell[33234, 851, 431, 8, 38, "Item",ExpressionUUID->"840a16d7-693a-4b32-ae1a-1e370522c6ee"],
Cell[33668, 861, 405, 9, 42, "Input",ExpressionUUID->"cf2de384-562b-4d6b-a801-b4583d5d5bde"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[34122, 876, 254, 4, 52, "Section",ExpressionUUID->"7273fb08-3ecb-4612-b7eb-afa453c5c5fc"],
Cell[CellGroupData[{
Cell[34401, 884, 164, 3, 43, "Subsection",ExpressionUUID->"89a43de3-c270-46ad-84ad-d6b21683d651"],
Cell[34568, 889, 759, 12, 38, "Item",ExpressionUUID->"5a344df8-dd61-4270-b2d0-d8e81a7442f5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35364, 906, 160, 3, 43, "Subsection",ExpressionUUID->"ba6497ea-09e5-4611-8c2c-ec56a430e499"],
Cell[35527, 911, 779, 13, 38, "Item",ExpressionUUID->"69db1212-7db6-4c8b-93d6-9d467dd802fc"],
Cell[36309, 926, 591, 11, 38, "Item",ExpressionUUID->"4527b5ec-2f2d-43c5-b326-92164ccaa9b6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36937, 942, 155, 3, 43, "Subsection",ExpressionUUID->"6ef4184d-5eb0-449f-9cbb-e20d06343312"],
Cell[37095, 947, 491, 9, 23, "Item",ExpressionUUID->"5f77f7ec-3099-484c-9113-42d5debb9873"],
Cell[37589, 958, 294, 6, 23, "Item",ExpressionUUID->"a35f6ffc-00e1-457c-a1e6-156c83c40e51"],
Cell[37886, 966, 340, 5, 23, "Item",ExpressionUUID->"af511de2-960b-4cfb-9dd6-4c1a575ebf94"]
}, Open  ]]
}, Closed]]
}
]
*)

